@@ -92,7 +92,7 @@ def enter_and_leave_function(func: Callable) -> Callable:
     return wrapper
 
 class SSHClient(object):
-    def __init__(self, ip="127.0.0.1", port=22, username="root", password="", connect_timeout=10):
+    def __init__(self, ip="127.0.0.1", port=22, username="root", password="", connect_timeout=10,get_tty=False):
         self.__ip = ip
         self.__port = port
         self.__username = username
@@ -100,6 +100,7 @@ class SSHClient(object):
         self.__connect_timeout = connect_timeout
         self.__ssh = None
         self.__sftp = None
+        self.__get_tty = get_tty
 
     @property
     def ip(self):
@@ -232,11 +233,18 @@ class SSHClient(object):
                 return_code = channel.recv_exit_status()
                 return ExecResult(return_code, output, stderr)
             else:
-                stdin, stdout, stderr = self.__ssh.exec_command(
-                    cmd,
-                    get_pty=True,
-                    timeout=timeout
-                )
+                if self.__get_tty:
+                    stdin, stdout, stderr = self.__ssh.exec_command(
+                        cmd,
+                        get_pty=True,
+                        timeout=timeout
+                    )
+                else:
+                    stdin, stdout, stderr = self.__ssh.exec_command(
+                        cmd,
+                        get_pty=False,
+                        timeout=timeout
+                    )
                 exit_status = stdout.channel.recv_exit_status()
                 std_output = stdout.read().decode()
                 std_err = stderr.read().decode()
